==> validation-model-arlington-1.23.65-sources.jar: org/verapdf/gf/model/impl/arlington/GFAMediaPlayers.java <==
/**
 * This file is part of veraPDF Validation, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.gf.model.impl.arlington;

import org.verapdf.cos.*;
import org.verapdf.model.alayer.*;
import org.verapdf.gf.model.impl.containers.StaticContainers;
import org.verapdf.tools.StaticResources;
import java.util.*;
import org.verapdf.pd.*;
import org.verapdf.as.ASAtom;
import java.util.stream.Collectors;
import org.verapdf.pd.structure.PDNumberTreeNode;

public class GFAMediaPlayers extends GFAObject implements AMediaPlayers {

	public GFAMediaPlayers(COSBase baseObject, COSBase parentObject, String keyName) {
		super(baseObject, parentObject, keyName, "AMediaPlayers");
	}

	@Override
	public List<? extends org.verapdf.model.baselayer.Object> getLinkedObjects(String link) {
		switch (link) {
			case "A":
				return getA();
			case "MU":
				return getMU();
			case "NU":
				return getNU();
			default:
				return super.getLinkedObjects(link);
		}
	}

	private List<AArrayOfMediaPlayerInfo> getA() {
		switch (StaticContainers.getFlavour()) {
			case ARLINGTON1_5:
			case ARLINGTON1_6:
			case ARLINGTON1_7:
			case ARLINGTON2_0:
				return getA1_5();
			default:
				return Collections.emptyList();
		}
	}

	private List<AArrayOfMediaPlayerInfo> getA1_5() {
		COSObject object = getAValue();
		if (object == null) {
			return Collections.emptyList();
		}
		if (object.getType() == COSObjType.COS_ARRAY) {
			List<AArrayOfMediaPlayerInfo> list = new ArrayList<>(1);
			list.add(new GFAArrayOfMediaPlayerInfo((COSArray)object.getDirectBase(), this.baseObject, "A"));
			return Collections.unmodifiableList(list);
		}
		return Collections.emptyList();
	}

	private List<AArrayOfMediaPlayerInfo> getMU() {
		switch (StaticContainers.getFlavour()) {
			case ARLINGTON1_5:
			case ARLINGTON1_6:
			case ARLINGTON1_7:
			case ARLINGTON2_0:
				return getMU1_5();
			default:
				return Collections.emptyList();
		}
	}

	private List<AArrayOfMediaPlayerInfo> getMU1_5() {
		COSObject object = getMUValue();
		if (object == null) {
			return Collections.emptyList();
		}
		if (object.getType() == COSObjType.COS_ARRAY) {
			List<AArrayOfMediaPlayerInfo> list = new ArrayList<>(1);
			list.add(new GFAArrayOfMediaPlayerInfo((COSArray)object.getDirectBase(), this.baseObject, "MU"));
			return Collections.unmodifiableList(list);
		}
		return Collections.emptyList();
	}

	private List<AArrayOfMediaPlayerInfo> getNU() {
		switch (StaticContainers.getFlavour()) {
			case ARLINGTON1_5:
			case ARLINGTON1_6:
			case ARLINGTON1_7:
			case ARLINGTON2_0:
				return getNU1_5();
			default:
				return Collections.emptyList();
		}
	}

	private List<AArrayOfMediaPlayerInfo> getNU1_5() {
		COSObject object = getNUValue();
		if (object == null) {
			return Collections.emptyList();
		}
		if (object.getType() == COSObjType.COS_ARRAY) {
			List<AArrayOfMediaPlayerInfo> list = new ArrayList<>(1);
			list.add(new GFAArrayOfMediaPlayerInfo((COSArray)object.getDirectBase(), this.baseObject, "NU"));
			return Collections.unmodifiableList(list);
		}
		return Collections.emptyList();
	}

	@Override
	public Boolean getcontainsA() {
		return this.baseObject.knownKey(ASAtom.getASAtom("A"));
	}

	public COSObject getAValue() {
		COSObject object = this.baseObject.getKey(ASAtom.getASAtom("A"));
		return object;
	}

	@Override
	public Boolean getAHasTypeArray() {
		COSObject object = getAValue();
		return object != null && object.getType() == COSObjType.COS_ARRAY;
	}

	@Override
	public Boolean getcontainsMU() {
		return this.baseObject.knownKey(ASAtom.getASAtom("MU"));
	}

	public COSObject getMUValue() {
		COSObject object = this.baseObject.getKey(ASAtom.getASAtom("MU"));
		return object;
	}

	@Override
	public Boolean getMUHasTypeArray() {
		COSObject object = getMUValue();
		return object != null && object.getType() == COSObjType.COS_ARRAY;
	}

	@Override
	public Long getMUArraySize() {
		COSObject object = getMUValue();
		if (object != null && object.getType() == COSObjType.COS_ARRAY) {
			return (long) object.size();
		}
		return null;
	}

	@Override
	public Boolean getcontainsNU() {
		return this.baseObject.knownKey(ASAtom.getASAtom("NU"));
	}

	public COSObject getNUValue() {
		COSObject object = this.baseObject.getKey(ASAtom.getASAtom("NU"));
		return object;
	}

	@Override
	public Boolean getNUHasTypeArray() {
		COSObject object = getNUValue();
		return object != null && object.getType() == COSObjType.COS_ARRAY;
	}

	@Override
	public Boolean getcontainsType() {
		return this.baseObject.knownKey(ASAtom.getASAtom("Type"));
	}

	public COSObject getTypeValue() {
		COSObject object = this.baseObject.getKey(ASAtom.getASAtom("Type"));
		return object;
	}

	@Override
	public Boolean getTypeHasTypeName() {
		COSObject object = getTypeValue();
		return object != null && object.getType() == COSObjType.COS_NAME;
	}

	@Override
	public String getTypeNameValue() {
		COSObject object = getTypeValue();
		if (object != null && object.getType() == COSObjType.COS_NAME) {
			return object.getString();
		}
		return null;
	}

}

==> validation-model-arlington-1.25.9-sources.jar: org/verapdf/gf/model/impl/arlington/GFAMediaPlayers.java <==
/**
 * This file is part of veraPDF Validation, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.gf.model.impl.arlington;

import org.verapdf.cos.*;
import org.verapdf.model.alayer.*;
import org.verapdf.gf.model.impl.containers.StaticContainers;
import org.verapdf.tools.StaticResources;
import java.util.*;
import org.verapdf.pd.PDNameTreeNode;
import org.verapdf.as.ASAtom;
import java.util.stream.Collectors;
import org.verapdf.pd.structure.PDNumberTreeNode;

public class GFAMediaPlayers extends GFAObject implements AMediaPlayers {

	public GFAMediaPlayers(COSBase baseObject, COSBase parentObject, String keyName) {
		super(baseObject, parentObject, keyName, "AMediaPlayers");
	}

	@Override
	public List<? extends org.verapdf.model.baselayer.Object> getLinkedObjects(String link) {
		switch (link) {
			case "A":
				return getA();
			case "MU":
				return getMU();
			case "NU":
				return getNU();
			default:
				return super.getLinkedObjects(link);
		}
	}

	private List<AArrayOfMediaPlayerInfo> getA() {
		switch (StaticContainers.getFlavour()) {
			case ARLINGTON1_5:
			case ARLINGTON1_6:
			case ARLINGTON1_7:
			case ARLINGTON2_0:
				return getA1_5();
			default:
				return Collections.emptyList();
		}
	}

	private List<AArrayOfMediaPlayerInfo> getA1_5() {
		COSObject object = getAValue();
		if (object == null) {
			return Collections.emptyList();
		}
		if (object.getType() == COSObjType.COS_ARRAY) {
			List<AArrayOfMediaPlayerInfo> list = new ArrayList<>(1);
			list.add(new GFAArrayOfMediaPlayerInfo((COSArray)object.getDirectBase(), this.baseObject, "A"));
			return Collections.unmodifiableList(list);
		}
		return Collections.emptyList();
	}

	private List<AArrayOfMediaPlayerInfo> getMU() {
		switch (StaticContainers.getFlavour()) {
			case ARLINGTON1_5:
			case ARLINGTON1_6:
			case ARLINGTON1_7:
			case ARLINGTON2_0:
				return getMU1_5();
			default:
				return Collections.emptyList();
		}
	}

	private List<AArrayOfMediaPlayerInfo> getMU1_5() {
		COSObject object = getMUValue();
		if (object == null) {
			return Collections.emptyList();
		}
		if (object.getType() == COSObjType.COS_ARRAY) {
			List<AArrayOfMediaPlayerInfo> list = new ArrayList<>(1);
			list.add(new GFAArrayOfMediaPlayerInfo((COSArray)object.getDirectBase(), this.baseObject, "MU"));
			return Collections.unmodifiableList(list);
		}
		return Collections.emptyList();
	}

	private List<AArrayOfMediaPlayerInfo> getNU() {
		switch (StaticContainers.getFlavour()) {
			case ARLINGTON1_5:
			case ARLINGTON1_6:
			case ARLINGTON1_7:
			case ARLINGTON2_0:
				return getNU1_5();
			default:
				return Collections.emptyList();
		}
	}

	private List<AArrayOfMediaPlayerInfo> getNU1_5() {
		COSObject object = getNUValue();
		if (object == null) {
			return Collections.emptyList();
		}
		if (object.getType() == COSObjType.COS_ARRAY) {
			List<AArrayOfMediaPlayerInfo> list = new ArrayList<>(1);
			list.add(new GFAArrayOfMediaPlayerInfo((COSArray)object.getDirectBase(), this.baseObject, "NU"));
			return Collections.unmodifiableList(list);
		}
		return Collections.emptyList();
	}

	@Override
	public Boolean getcontainsA() {
		return this.baseObject.knownKey(ASAtom.getASAtom("A"));
	}

	public COSObject getAValue() {
		COSObject object = this.baseObject.getKey(ASAtom.getASAtom("A"));
		return object;
	}

	@Override
	public Boolean getAHasTypeArray() {
		COSObject object = getAValue();
		return getHasTypeArray(object);
	}

	@Override
	public Boolean getcontainsMU() {
		return this.baseObject.knownKey(ASAtom.getASAtom("MU"));
	}

	public COSObject getMUValue() {
		COSObject object = this.baseObject.getKey(ASAtom.getASAtom("MU"));
		return object;
	}

	@Override
	public Boolean getMUHasTypeArray() {
		COSObject object = getMUValue();
		return getHasTypeArray(object);
	}

	@Override
	public Long getMUArraySize() {
		COSObject object = getMUValue();
		return getArraySize(object);
	}

	@Override
	public Boolean getcontainsNU() {
		return this.baseObject.knownKey(ASAtom.getASAtom("NU"));
	}

	public COSObject getNUValue() {
		COSObject object = this.baseObject.getKey(ASAtom.getASAtom("NU"));
		return object;
	}

	@Override
	public Boolean getNUHasTypeArray() {
		COSObject object = getNUValue();
		return getHasTypeArray(object);
	}

	@Override
	public Boolean getcontainsType() {
		return this.baseObject.knownKey(ASAtom.getASAtom("Type"));
	}

	public COSObject getTypeValue() {
		COSObject object = this.baseObject.getKey(ASAtom.getASAtom("Type"));
		return object;
	}

	@Override
	public Boolean getTypeHasTypeName() {
		COSObject object = getTypeValue();
		return getHasTypeName(object);
	}

	@Override
	public String getTypeNameValue() {
		COSObject object = getTypeValue();
		return getNameValue(object);
	}

}
